"_PACKAGE"

#' @title Storing, Manipulating and Analysis Spectroscopy and Associated Data in R
#' @name spectacles-package
#' @description Stores and eases the manipulation of spectra and associated data.
#' @author Pierre Roudier
NULL
